==> cx-24.2.1.tgz: package/src/charts/Chart.js <==
import { Widget, VDOM, getContent } from '../ui/Widget';
import { BoundedObject } from '../svg/BoundedObject';
import { Axis } from './axis/Axis';

export class Chart extends BoundedObject {

   init() {
      super.init();

      if (!this.axes)
         this.axes = {};

      for (let axis in this.axes) {
         this.axes[axis] = Axis.create(this.axes[axis]);
      }
   }

   explore(context, instance) {

      instance.calculators = { ...context.axes };

      context.push('axes', instance.calculators);
      instance.axes = {};

      //axes need to be registered before children to be processed first
      for (let axis in this.axes) {
         let axisInstance = instance.getChild(context, this.axes[axis]);
         if (axisInstance.scheduleExploreIfVisible(context)) {
            instance.axes[axis] = axisInstance;
            instance.calculators[axis] = this.axes[axis].report(context, axisInstance);
         }
      }

      super.explore(context, instance);
   }

   exploreCleanup(context, instance) {
      context.pop('axes');
   }

   prepare(context, instance) {
      context.push('axes', instance.calculators);
      super.prepare(context, instance);
   }

   prepareCleanup(context, instance) {
      context.pop('axes');
      super.prepareCleanup(context, instance);
   }

   render(context, instance, key) {
      let axes = [];
      for (let k in instance.axes) {
         axes.push(getContent(instance.axes[k].render(context, key + "-axis-" + k)));
      }

      let result = [];

      if (!this.axesOnTop)
         result.push(axes);

      result.push(this.renderChildren(context, instance));

      if (this.axesOnTop)
         result.push(axes);

      return result;
   }
}

Chart.prototype.anchors = '0 1 1 0';
Chart.prototype.styled = true;
Chart.prototype.isPureContainer = true;
Chart.prototype.axesOnTop = false;

Widget.alias('chart', Chart);

==> cx-25.4.0.tgz: package/src/charts/Chart.js <==
import { Widget, VDOM, getContent } from "../ui/Widget";
import { BoundedObject } from "../svg/BoundedObject";
import { Axis } from "./axis/Axis";

export class Chart extends BoundedObject {
   init() {
      super.init();

      if (!this.axes) this.axes = {};

      for (let axis in this.axes) {
         this.axes[axis] = Axis.create(this.axes[axis]);
      }
   }

   explore(context, instance) {
      instance.calculators = { ...context.axes };

      context.push("axes", instance.calculators);
      instance.axes = {};

      //axes need to be registered before children to be processed first
      for (let axis in this.axes) {
         let axisInstance = instance.getChild(context, this.axes[axis]);
         if (axisInstance.scheduleExploreIfVisible(context)) {
            instance.axes[axis] = axisInstance;
            instance.calculators[axis] = this.axes[axis].report(context, axisInstance);
         }
      }

      super.explore(context, instance);
   }

   exploreCleanup(context, instance) {
      context.pop("axes");

      for (let axis in instance.axes) {
         instance.axes[axis].widget.reportData(context, instance.axes[axis]);
      }
   }

   prepare(context, instance) {
      context.push("axes", instance.calculators);
      super.prepare(context, instance);
   }

   prepareCleanup(context, instance) {
      context.pop("axes");
      super.prepareCleanup(context, instance);
   }

   render(context, instance, key) {
      let axes = [];
      for (let k in instance.axes) {
         axes.push(getContent(instance.axes[k].render(context, key + "-axis-" + k)));
      }

      let result = [];

      if (!this.axesOnTop) result.push(axes);

      result.push(this.renderChildren(context, instance));

      if (this.axesOnTop) result.push(axes);

      return result;
   }
}

Chart.prototype.anchors = "0 1 1 0";
Chart.prototype.styled = true;
Chart.prototype.isPureContainer = true;
Chart.prototype.axesOnTop = false;

Widget.alias("chart", Chart);
